@@ -28,9 +28,9 @@
 
 #include "layers/selections/text/kpTextStyle.h"
 
-#include <qdatastream.h>
-#include <qfont.h>
-#include <qfontmetrics.h>
+#include <QDataStream>
+#include <QFont>
+#include <QFontMetrics>
 
 
 kpTextStyle::kpTextStyle ()
@@ -56,9 +56,7 @@ kpTextStyle::kpTextStyle (const QString &fontFamily,
 {
 }
 
-kpTextStyle::~kpTextStyle ()
-{
-}
+kpTextStyle::~kpTextStyle () = default;
 
 
 // friend
