@@ -42,7 +42,6 @@
 
 #include <QWidget>
 
-#include <kiconloader.h>
 #include <KLocalizedString>
 
 //---------------------------------------------------------------------
@@ -78,7 +77,7 @@ kpToolZoom::kpToolZoom (kpToolEnvironment *environ, QWidget *parent)
       d (new kpToolZoomPrivate ())
 {
   // different from objectName()
-  action()->setIcon(KDE::icon(QStringLiteral("zoom-original")));
+  action()->setIcon(QIcon::fromTheme(QStringLiteral("zoom-original")));
 }
 
 //---------------------------------------------------------------------
