@@ -60,8 +60,9 @@ void kpView::mouseMoveEvent (QMouseEvent *e)
     //       of the mainView.
     setHasMouse (rect ().contains (e->pos ()));
 
-    if (tool ())
+    if (tool ()) {
         tool ()->mouseMoveEvent (e);
+    }
 
     e->accept ();
 }
@@ -77,8 +78,9 @@ void kpView::mousePressEvent (QMouseEvent *e)
 
     setHasMouse (true);
 
-    if (tool ())
+    if (tool ()) {
         tool ()->mousePressEvent (e);
+    }
 
     e->accept ();
 }
@@ -96,8 +98,9 @@ void kpView::mouseReleaseEvent (QMouseEvent *e)
 
     setHasMouse (rect ().contains (e->pos ()));
 
-    if (tool ())
+    if (tool ()) {
         tool ()->mouseReleaseEvent (e);
+    }
 
     e->accept ();
 }
@@ -107,8 +110,9 @@ void kpView::mouseReleaseEvent (QMouseEvent *e)
 // public virtual [base QWidget]
 void kpView::wheelEvent (QWheelEvent *e)
 {
-    if (tool ())
+    if (tool ()) {
         tool ()->wheelEvent (e);
+    }
 }
 
 //---------------------------------------------------------------------
@@ -120,8 +124,9 @@ void kpView::keyPressEvent (QKeyEvent *e)
     qCDebug(kpLogViews) << "kpView(" << objectName () << ")::keyPressEvent()" << e->text();
 #endif
 
-    if (tool ())
+    if (tool ()) {
         tool ()->keyPressEvent (e);
+    }
 
     e->accept ();
 }
@@ -135,8 +140,9 @@ void kpView::keyReleaseEvent (QKeyEvent *e)
     qCDebug(kpLogViews) << "kpView(" << objectName () << ")::keyReleaseEvent()";
 #endif
 
-    if (tool ())
+    if (tool ()) {
         tool ()->keyReleaseEvent (e);
+    }
 
     e->accept ();
 }
@@ -150,8 +156,9 @@ void kpView::inputMethodEvent (QInputMethodEvent *e)
     qCDebug(kpLogViews) << "kpView(" << objectName () << ")::inputMethodEvent()";
 #endif
 
-    if (tool ())
+    if (tool ()) {
         tool ()->inputMethodEvent (e);
+    }
     e->accept ();
 }
 
@@ -182,8 +189,9 @@ void kpView::focusInEvent (QFocusEvent *e)
 #if DEBUG_KP_VIEW && 0
     qCDebug(kpLogViews) << "kpView(" << objectName () << ")::focusInEvent()";
 #endif
-    if (tool ())
+    if (tool ()) {
         tool ()->focusInEvent (e);
+    }
 }
 
 // protected virtual [base QWidget]
@@ -192,8 +200,9 @@ void kpView::focusOutEvent (QFocusEvent *e)
 #if DEBUG_KP_VIEW && 0
     qCDebug(kpLogViews) << "kpView(" << objectName () << ")::focusOutEvent()";
 #endif
-    if (tool ())
+    if (tool ()) {
         tool ()->focusOutEvent (e);
+    }
 }
 
 
@@ -215,8 +224,9 @@ void kpView::enterEvent (QEvent *e)
     // while RMB menu was up) and hence the cursor is not updated.
     setHasMouse (true);
 
-    if (tool ())
+    if (tool ()) {
         tool ()->enterEvent (e);
+    }
 }
 
 // protected virtual [base QWidget]
@@ -227,8 +237,9 @@ void kpView::leaveEvent (QEvent *e)
 #endif
 
     setHasMouse (false);
-    if (tool ())
+    if (tool ()) {
         tool ()->leaveEvent (e);
+    }
 }
 
 
