@@ -52,13 +52,13 @@ public:
     // kpEffectWidgetBase interface
     //
 
-    virtual QString caption () const;
+    QString caption () const override;
 
-    virtual bool isNoOp () const;
-    virtual kpImage applyEffect (const kpImage &image);
+    bool isNoOp () const override;
+    kpImage applyEffect (const kpImage &image) override;
 
-    virtual kpEffectCommandBase *createCommand (
-        kpCommandEnvironment *cmdEnviron) const;
+    kpEffectCommandBase *createCommand (
+        kpCommandEnvironment *cmdEnviron) const override;
 
 protected:
     QRadioButton *m_blackAndWhiteRadioButton,
