@@ -32,7 +32,6 @@
 #include <QSlider>
 #include <QStyle>
 
-#include <KConfigDialogManager>
 #include <KLocalizedString>
 
 static inline int calcDiffByTen(int x, int y)
@@ -52,7 +51,7 @@ public:
         column2Width(0),
         label(nullptr),
         slider(nullptr),
-        labelAlignment(nullptr)
+        labelAlignment()
     {
     }
 
@@ -78,9 +77,6 @@ kpNumInput::kpNumInput(QWidget *parent)
 {
     setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
     setFocusPolicy(Qt::StrongFocus);
-    KConfigDialogManager::changedMap()->insert(QStringLiteral("kpIntNumInput"), SIGNAL(valueChanged(int)));
-    KConfigDialogManager::changedMap()->insert(QStringLiteral("QSpinBox"), SIGNAL(valueChanged(int)));
-    KConfigDialogManager::changedMap()->insert(QStringLiteral("kpDoubleSpinBox"), SIGNAL(valueChanged(double)));
 }
 
 kpNumInput::~kpNumInput()
@@ -103,7 +99,7 @@ void kpNumInput::setLabel(const QString &label, Qt::Alignment a)
     if (label.isEmpty()) {
         delete d->label;
         d->label = nullptr;
-        d->labelAlignment = nullptr;
+        d->labelAlignment = {};
     } else {
         if (!d->label) {
             d->label = new QLabel(this);
@@ -319,8 +315,7 @@ QSize kpIntNumInput::minimumSizeHint() const
         h = qMax(h, priv->labelSize.height() + 2);
     }
 
-    const int spacingHint = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
-    w = priv->slider ? priv->slider->sizeHint().width() + spacingHint : 0;
+    w = priv->slider ? priv->slider->sizeHint().width() : 0;
     w += priv->column1Width + priv->column2Width;
 
     if (priv->labelAlignment & (Qt::AlignTop | Qt::AlignBottom)) {
@@ -348,7 +343,7 @@ void kpIntNumInput::resizeEvent(QResizeEvent *e)
 
     int w = priv->column1Width;
     int h = 0;
-    const int spacingHint = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacingHint = 0;//style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     if (priv->label && (priv->labelAlignment & Qt::AlignTop)) {
         priv->label->setGeometry(0, 0, e->size().width(), priv->labelSize.height());
@@ -528,7 +523,7 @@ QSize kpDoubleNumInput::minimumSizeHint() const
         h = qMax(h, priv->labelSize.height() + 2);
     }
 
-    const int spacingHint = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacingHint = 0;//style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
     w = priv->slider ? priv->slider->sizeHint().width() + spacingHint : 0;
     w += priv->column1Width + priv->column2Width;
 
@@ -545,7 +540,7 @@ void kpDoubleNumInput::resizeEvent(QResizeEvent *e)
 
     int w = priv->column1Width;
     int h = 0;
-    const int spacingHint = style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
+    const int spacingHint = 0;//style()->pixelMetric(QStyle::PM_DefaultLayoutSpacing);
 
     if (priv->label && (priv->labelAlignment & Qt::AlignTop)) {
         priv->label->setGeometry(0, 0, e->size().width(), priv->labelSize.height());
